@@ -9,7 +9,9 @@ from . import open_solvers
 from . import bounded_solvers
 from . import iterative_solvers
 from . import least_squares_iteration
+from . import problem_list
 from . import profiler
+from . import problem
 from . import utils
 from . import fast
 
@@ -17,6 +19,8 @@ __all__ = (*open_solvers.__all__,
            *bounded_solvers.__all__,
            *iterative_solvers.__all__,
            *least_squares_iteration.__all__,
+           *problem_list.__all__,
+           *problem.__all__,
            *profiler.__all__,
            *jit_speed.__all__,
            'utils',
@@ -28,4 +32,6 @@ from .open_solvers import *
 from .bounded_solvers import *
 from .iterative_solvers import *
 from .least_squares_iteration import *
+from .problem_list import *
+from .problem import *
 from .profiler import *
\ No newline at end of file
