@@ -89,7 +89,7 @@ def fixedpoint_converged(dx, xtol):
         return scalar_fixedpoint_converged(dx, xtol)
 
 @overload(fixedpoint_converged)
-def fixedpoint_converged(dx, xtol):
+def jit_fixedpoint_converged(dx, xtol):
     if isinstance(dx, types.Array) and dx.ndim:
         return array_fixedpoint_converged
     else:
@@ -146,7 +146,7 @@ def IQ_iter(y0, y1, y2, x0, x1, x2, dx, df0, xlast):
     d01 = df0-df1
     d02 = df0-df2
     d12 = df1-df2
-    if abs(d01) > 1e-32 and abs(d02) > 1e-32 and abs(d12) > 1e-32:
+    if abs(d01) > 1e-16 and abs(d02) > 1e-16 and abs(d12) > 1e-16:
         df0_d12 = df0 / d12
         df1_d02 = df1 / d02
         df2_d01 = df2 / d01
@@ -158,11 +158,19 @@ def IQ_iter(y0, y1, y2, x0, x1, x2, dx, df0, xlast):
     return x
 
 @njitable(cache=True)
-def raise_root_error(not_satisfied):
-    if not_satisfied:
-        raise RuntimeError('root could not be solved within error tolerance')
+def raise_iter_error():
+    raise RuntimeError('maximum number of iterations exceeded; root could not be solved')
         
 @njitable(cache=True)
-def raise_bounds_error(y0, y1):
+def raise_tol_error():
+    raise RuntimeError('minimum tolerance reached; root could not be solved')
+
+@njitable(cache=True)
+def check_tols(xtol, ytol):        
+    if xtol !=0. and ytol != 0.:
+        raise ValueError("xtol and ytol must be postive to check root")
+
+@njitable(cache=True)
+def check_bounds(y0, y1):        
     if y0 * y1 > 0.:
-        raise RuntimeError('f(x0) and f(x1) must have opposite signs')
\ No newline at end of file
+        raise ValueError('f(x0) and f(x1) must have opposite signs')
\ No newline at end of file
